document.addEventListener('DOMContentLoaded', () => {
  // Animate counters
  const counters = document.querySelectorAll('.counter');
  
  const animateCounter = (counter) => {
    const target = parseInt(counter.getAttribute('data-target'));
    const duration = 2000; // 2 seconds
    const steps = 50;
    const stepValue = target / steps;
    let current = 0;
    
    const updateCounter = () => {
      current += stepValue;
      if (current < target) {
        counter.textContent = Math.ceil(current);
        setTimeout(updateCounter, duration / steps);
      } else {
        counter.textContent = target;
      }
    };
    
    updateCounter();
  };

  // Intersection Observer for counters
  const counterObserver = new IntersectionObserver((entries) => {
    entries.forEach(entry => {
      if (entry.isIntersecting) {
        animateCounter(entry.target);
        counterObserver.unobserve(entry.target);
      }
    });
  });

  counters.forEach(counter => counterObserver.observe(counter));

  // Animate percentage bars
  const percentages = document.querySelectorAll('.percentage');
  
  const percentageObserver = new IntersectionObserver((entries) => {
    entries.forEach(entry => {
      if (entry.isIntersecting) {
        const bar = entry.target;
        const value = bar.getAttribute('data-value');
        bar.style.setProperty('--width', `${value}%`);
        bar.querySelector('::after').style.width = `${value}%`;
        percentageObserver.unobserve(bar);
      }
    });
  });

  percentages.forEach(percentage => {
    const value = percentage.getAttribute('data-value');
    percentage.style.setProperty('--width', '0%');
    percentageObserver.observe(percentage);
  });
});
